==> ogre-docs-1.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_g_l_hardware_pixel_buffer_common.js <==
var class_ogre_1_1_g_l_hardware_pixel_buffer_common =
[
    [ "Usage", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630", [
      [ "HBU_STATIC", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a6f26f67ab31d60248314c9c6c77c9edb", null ],
      [ "HBU_DYNAMIC", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630abec61c14b13652a06566a79afd6f7518", null ],
      [ "HBU_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a2fe20ff00e9acb928a2d9680f0c505e2", null ],
      [ "HBU_DISCARDABLE", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a246699879ba7647973a2d8ed86acf76f", null ],
      [ "HBU_STATIC_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a5ffbb339becd31435c5f616be4c28996", null ],
      [ "HBU_DYNAMIC_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630aa0c82d1b27d6cc04e4b5f6d47a22a74c", null ],
      [ "HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a29ff2e0fd2b408359e84291b27282516", null ]
    ] ],
    [ "LockOptions", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0f", [
      [ "HBL_NORMAL", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0fae11601d29cd56aad7ea7a1b23a688b0e", null ],
      [ "HBL_DISCARD", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0fa176ad39ac15fc0a6028d820a6fe228ae", null ],
      [ "HBL_READ_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0faa364c1511514cd4d7ee1e7092eb41288", null ],
      [ "HBL_NO_OVERWRITE", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0fa32a2f7b1c3430cc9c3f0f665934d0c4a", null ],
      [ "HBL_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0faf4acad29e302c7c02ce72c3fce8990df", null ]
    ] ],
    [ "GLHardwarePixelBufferCommon", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ac628168598d3507f6987996becd6d5ef", null ],
    [ "~GLHardwarePixelBufferCommon", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a69ad3e715ffb3f4b542ffbbe5a52e644", null ],
    [ "bindToFramebuffer", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#af966e7c5a3df713d8a7eec1687f71f7b", null ],
    [ "getGLFormat", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a508718a40171116e95522507bab1bd8f", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a30312407a4ece07e205b66eadf31363e", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a8aaa214f42a683f7203ed42f8c0caf17", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a93b204642190e611bc226ea08d29160e", null ],
    [ "getCurrentLock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a9f888e279109a05b5228f71c5b8f9d34", null ],
    [ "readData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#abbd6dece7babe2473adc396bb458f53c", null ],
    [ "writeData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a117ff90e202f525c2a4b7bb9c51eb4df", null ],
    [ "blit", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a51df5ef5580e242fc11a40f64bb1cb17", null ],
    [ "blit", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ad4a77bfe5a38c59300124e6cf6305b9e", null ],
    [ "blitFromMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae12e40bc3a6461d93b7bfae20e58c866", null ],
    [ "blitFromMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a2405dade15f595710a02903d302155bd", null ],
    [ "blitToMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ad46d21527ad100d90cce2294d2157170", null ],
    [ "blitToMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a3d9ff2acd7776be35efd6fa24307012c", null ],
    [ "getRenderTarget", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aadcc10954fe5d710eb8cde1ebf0082a3", null ],
    [ "getWidth", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a08822dca42177445a88fe1a712a0420e", null ],
    [ "getHeight", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aff12f280560ed62d89782d7986b58a36", null ],
    [ "getDepth", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#adf9e3e1adce1c03b95ebddd2e29781ea", null ],
    [ "getFormat", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a671112bc97923b41d318ffddc94f0c56", null ],
    [ "unlock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a64ddd429ff2c8ac4f0cca5decb5c6757", null ],
    [ "copyData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a721891f0c0bd391dd5848c8a585ba054", null ],
    [ "copyData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a0bf3147b1f99a81dd84fb7b978c4686d", null ],
    [ "_updateFromShadow", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a344c52f2214eaff097d5fbc390e7684b", null ],
    [ "getSizeInBytes", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a9194c7e8b536f4825b15b9e6a6912ce8", null ],
    [ "getUsage", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a9c5ee6468dcb269e422e213b82726e4f", null ],
    [ "isSystemMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a0e1881a6106c59d5aae27589ca1bca5d", null ],
    [ "hasShadowBuffer", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a40a623d95552d9b1858e5c300a3ad68c", null ],
    [ "isLocked", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a7c874c6b30c39aa38ae0d6abe2ba42bc", null ],
    [ "suppressHardwareUpdate", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a688e1be4a913099ce5e06172771e2d45", null ]
];

==> ogre-docs-1.12.1-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_g_l_hardware_pixel_buffer_common.js <==
var class_ogre_1_1_g_l_hardware_pixel_buffer_common =
[
    [ "Usage", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630", [
      [ "HBU_STATIC", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a6f26f67ab31d60248314c9c6c77c9edb", null ],
      [ "HBU_DYNAMIC", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630abec61c14b13652a06566a79afd6f7518", null ],
      [ "HBU_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a2fe20ff00e9acb928a2d9680f0c505e2", null ],
      [ "HBU_DISCARDABLE", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a246699879ba7647973a2d8ed86acf76f", null ],
      [ "HBU_STATIC_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a5ffbb339becd31435c5f616be4c28996", null ],
      [ "HBU_DYNAMIC_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630aa0c82d1b27d6cc04e4b5f6d47a22a74c", null ],
      [ "HBU_DYNAMIC_WRITE_ONLY_DISCARDABLE", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae51f5970d879af736e4cf53e1ec46630a29ff2e0fd2b408359e84291b27282516", null ]
    ] ],
    [ "LockOptions", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0f", [
      [ "HBL_NORMAL", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0fae11601d29cd56aad7ea7a1b23a688b0e", null ],
      [ "HBL_DISCARD", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0fa176ad39ac15fc0a6028d820a6fe228ae", null ],
      [ "HBL_READ_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0faa364c1511514cd4d7ee1e7092eb41288", null ],
      [ "HBL_NO_OVERWRITE", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0fa32a2f7b1c3430cc9c3f0f665934d0c4a", null ],
      [ "HBL_WRITE_ONLY", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aac34930556f611928ec9157c04bd1b0faf4acad29e302c7c02ce72c3fce8990df", null ]
    ] ],
    [ "GLHardwarePixelBufferCommon", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ac628168598d3507f6987996becd6d5ef", null ],
    [ "~GLHardwarePixelBufferCommon", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a69ad3e715ffb3f4b542ffbbe5a52e644", null ],
    [ "bindToFramebuffer", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#af966e7c5a3df713d8a7eec1687f71f7b", null ],
    [ "getGLFormat", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a508718a40171116e95522507bab1bd8f", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a30312407a4ece07e205b66eadf31363e", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a8aaa214f42a683f7203ed42f8c0caf17", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ab1caebda1f7442706df97531c2d90aaf", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a93b204642190e611bc226ea08d29160e", null ],
    [ "lock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a93b204642190e611bc226ea08d29160e", null ],
    [ "getCurrentLock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a9f888e279109a05b5228f71c5b8f9d34", null ],
    [ "readData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#abbd6dece7babe2473adc396bb458f53c", null ],
    [ "writeData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a117ff90e202f525c2a4b7bb9c51eb4df", null ],
    [ "blit", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a51df5ef5580e242fc11a40f64bb1cb17", null ],
    [ "blit", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ad4a77bfe5a38c59300124e6cf6305b9e", null ],
    [ "blitFromMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ae12e40bc3a6461d93b7bfae20e58c866", null ],
    [ "blitFromMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a2405dade15f595710a02903d302155bd", null ],
    [ "blitToMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#ad46d21527ad100d90cce2294d2157170", null ],
    [ "blitToMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a3d9ff2acd7776be35efd6fa24307012c", null ],
    [ "getRenderTarget", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aadcc10954fe5d710eb8cde1ebf0082a3", null ],
    [ "getWidth", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a08822dca42177445a88fe1a712a0420e", null ],
    [ "getHeight", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#aff12f280560ed62d89782d7986b58a36", null ],
    [ "getDepth", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#adf9e3e1adce1c03b95ebddd2e29781ea", null ],
    [ "getFormat", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a671112bc97923b41d318ffddc94f0c56", null ],
    [ "unlock", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a64ddd429ff2c8ac4f0cca5decb5c6757", null ],
    [ "copyData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a721891f0c0bd391dd5848c8a585ba054", null ],
    [ "copyData", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a0bf3147b1f99a81dd84fb7b978c4686d", null ],
    [ "_updateFromShadow", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a344c52f2214eaff097d5fbc390e7684b", null ],
    [ "getSizeInBytes", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a9194c7e8b536f4825b15b9e6a6912ce8", null ],
    [ "getUsage", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a9c5ee6468dcb269e422e213b82726e4f", null ],
    [ "isSystemMemory", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a0e1881a6106c59d5aae27589ca1bca5d", null ],
    [ "hasShadowBuffer", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a40a623d95552d9b1858e5c300a3ad68c", null ],
    [ "isLocked", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a7c874c6b30c39aa38ae0d6abe2ba42bc", null ],
    [ "suppressHardwareUpdate", "class_ogre_1_1_g_l_hardware_pixel_buffer_common.html#a688e1be4a913099ce5e06172771e2d45", null ]
];
